@@ -6,7 +6,7 @@
 # Change 1..1 below to 1..last_test_to_print .
 # (It may become useful if the test is moved to ./t subdirectory.)
 
-BEGIN { $| = 1; print "1..6\n"; }
+BEGIN { $| = 1; print "1..7\n"; }
 END {print "not ok 1\n" unless $loaded;}
 use Games::QuizTaker;
 $loaded = 1;
@@ -18,22 +18,22 @@ $loaded = 1;
 # (correspondingly "not ok 13") depending on the success of chunk 13
 # of the test code):
 
-$Q1=Games::QuizTaker->new({-FileName=>"sampleqa"});
-if($$Q1{-FileName} eq "sampleqa"){
-  print"{-FileName} .......... ok 2\n";
+$Q1=Games::QuizTaker->new(FileName=>"sampleqa");
+if($$Q1{_FileName} eq "sampleqa"){
+  print"{_FileName} .......... ok 2\n";
 }else{
-  print"{-FileName} .......... not ok 2\n";
+  print"{_FileName} .......... not ok 2\n";
 }
-if($$Q1{-Delimitor} eq "|"){
-  print"{-Delimitor} ......... ok 3\n";
+if($$Q1{_Delimiter} eq "|"){
+  print"{_Delimiter} ......... ok 3\n";
 }else{
-  print"{-Delimitor} ......... not ok 3\n";
+  print"{_Delimiter} ......... not ok 3\n";
 }
-$Q2=Games::QuizTaker->new({-FileName=>"sample.csv",-Delimitor=>","});
-if($$Q2{-Delimitor} eq ","){
-  print"{-Delimitor} init .... ok 4\n";
+$Q2=Games::QuizTaker->new(FileName=>"sample.csv",Delimiter=>",");
+if($$Q2{_Delimiter} eq ","){
+  print"{_Delimiter} init .... ok 4\n";
 }else{
-  print"{-Delimitor} init .... not ok 4\n";
+  print"{_Delimiter} init .... not ok 4\n";
 }
 my %hash=();
 my $refhash=$Q1->load(\%hash);
@@ -50,5 +50,10 @@ if($num == 9){
 }else{
   print"Generate function .... not ok 6\n";
 }
-
+my $V=$Q2->_Get_VERSION;
+if($V=~/^\d\.\d{2}/){
+  print"Version function ..... ok 7\n";
+}else{
+  print"Version function ..... not ok 7\n";
+}
 
